NodeLinker

Enum NodeLinker 

pub enum NodeLinker {
    Isolated,
    Hoisted,
    Pnp,
}
Defines what linker should be used for installing Node packages. See more: https://pnpm.io/settings#nodelinker

Variants



Isolated

Dependencies are symlinked from a virtual store at node_modules/.pnpm



Hoisted

A flat node_modules without symlinks is created.



Pnp

No node_modules. Plug’n’Play is an innovative strategy for Node that is used by Yarn Berry. It is recommended to also set symlink setting to false when using pnp as your linker.