ResolutionMode

Enum ResolutionMode 

pub enum ResolutionMode {
    Highest,
    LowestDirect,
    TimeBased,
}
Determines how pnpm resolves dependencies. See more: https://pnpm.io/settings#resolutionmode

Variants



Highest

Dependencies will be resolved to their highest versions.



LowestDirect

Direct dependencies will be resolved to their lowest versions.



TimeBased

When resolutionMode is set to time-based, dependencies will be resolved the following way: Direct dependencies will be resolved to their lowest versions. So if there is foo@^1.1.0 in the dependencies, then 1.1.0 will be installed. Subdependencies will be resolved from versions that were published before the last direct dependency was published.