VerifyDepsBeforeRun

Enum VerifyDepsBeforeRun 

pub enum VerifyDepsBeforeRun {
    Install,
    Warn,
    Error,
    Prompt,
    Bool(bool),
}
This setting allows the checking of the state of dependencies before running scripts. See more: https://pnpm.io/settings#verifydepsbeforerun

Variants



Install

Automatically runs install if node_modules is not up to date.



Warn

Prints a warning if node_modules is not up to date.



Error

Throws an error if node_modules is not up to date.



Prompt

Prompts the user for permission to run install if node_modules is not up to date.



Bool(bool)