PackageExtension

Struct PackageExtension 

pub struct PackageExtension {
    pub dependencies: Option<BTreeMap<String, String>>,
    pub dev_dependencies: Option<BTreeMap<String, String>>,
    pub optional_dependencies: Option<BTreeMap<String, String>>,
    pub peer_dependencies: Option<BTreeMap<String, String>>,
    pub peer_dependencies_meta: Option<BTreeMap<String, PeerDependencyMeta>>,
}
Package extensions offer a way to extend the existing package definitions with additional information. For example, if react-redux should have react-dom in its peerDependencies but it has not, it is possible to patch react-redux using packageExtensions. See more: https://pnpm.io/settings#packageextensions

Fields

dependencies: Option<BTreeMap<String, String>>

Dependencies are specified with a simple hash of package name to version range. The version range is a string which has one or more space-separated descriptors. Dependencies can also be identified with a tarball or git URL.

dev_dependencies: Option<BTreeMap<String, String>>

Specifies dependencies that are required for the development and testing of the project. These dependencies are not needed in the production environment.

optional_dependencies: Option<BTreeMap<String, String>>

Specifies dependencies that are optional for your project. These dependencies are attempted to be installed during the npm install process, but if they fail to install, the installation process will not fail.

peer_dependencies: Option<BTreeMap<String, String>>

Specifies dependencies that are required by the package but are expected to be provided by the consumer of the package.

peer_dependencies_meta: Option<BTreeMap<String, PeerDependencyMeta>>

When a user installs your package, warnings are emitted if packages specified in “peerDependencies” are not already installed. The “peerDependenciesMeta” field serves to provide more information on how your peer dependencies are utilized. Most commonly, it allows peer dependencies to be marked as optional. Metadata for this field is specified with a simple hash of the package name to a metadata object.