pub struct PeerDependencyMeta {
pub optional: Option<bool>,
pub extras: BTreeMap<String, Value>,
}Expand description
When a user installs your package, warnings are emitted if packages specified in “peerDependencies” are not already installed. The “peerDependenciesMeta” field serves to provide more information on how your peer dependencies are utilized. Most commonly, it allows peer dependencies to be marked as optional. Metadata for this field is specified with a simple hash of the package name to a metadata object.
Fields
optional: Option<bool>Specifies that this peer dependency is optional and should not be installed automatically.
extras: BTreeMap<String, Value>Trait Implementations
Sourceimpl Clone for PeerDependencyMeta
impl Clone for PeerDependencyMeta
Sourcefn clone(&self) -> PeerDependencyMeta
fn clone(&self) -> PeerDependencyMeta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PeerDependencyMeta
impl Debug for PeerDependencyMeta
Sourceimpl Default for PeerDependencyMeta
impl Default for PeerDependencyMeta
Sourcefn default() -> PeerDependencyMeta
fn default() -> PeerDependencyMeta
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PeerDependencyMetawhere
PeerDependencyMeta: Default,
impl<'de> Deserialize<'de> for PeerDependencyMetawhere
PeerDependencyMeta: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PeerDependencyMeta
impl PartialEq for PeerDependencyMeta
Sourceimpl Serialize for PeerDependencyMeta
impl Serialize for PeerDependencyMeta
impl Eq for PeerDependencyMeta
impl StructuralPartialEq for PeerDependencyMeta