pub enum CatalogMode {
Manual,
Strict,
Prefer,
}Expand description
Controlls if and how dependencies are added to the default catalog, when running pnpm add. See more: https://pnpm.io/settings#catalogmode
Variants
Manual
(default) - does not automatically add dependencies to the catalog.
Strict
Only allows dependency versions from the catalog. Adding a dependency outside the catalog’s version range will cause an error.
Prefer
Prefers catalog versions, but will fall back to direct dependencies if no compatible version is found.