pub enum PackageImportMethod {
Auto,
Hardlink,
Clone,
CloneOrCopy,
Copy,
}Expand description
Controls the way packages are imported from the store (if you want to disable symlinks inside node_modules, then you need to change the nodeLinker setting, not this one). See more: https://pnpm.io/settings#packageimportmethod
Variants
Auto
Try to clone packages from the store. If cloning is not supported then hardlink packages from the store. If neither cloning nor linking is possible, fall back to copying.
Hardlink
Hard link packages from the store.
Clone
Clone (AKA copy-on-write or reference link) packages from the store.
CloneOrCopy
Try to clone packages from the store. If cloning is not supported then fall back to copying.
Copy
Copy packages from the store.